@@ -2,7 +2,7 @@ import logging
 
 from logzero import setup_logger
 
-import curia.api.swagger_client as swagger_client
+from curia.api import swagger_client
 from curia.api.swagger_client import configuration
 
 DEFAULT_LOG_LEVEL = logging.INFO
